<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:wb="http://schema.bmwfw.gv.at/vii/wissensbilanz2">
	<xsl:output method="html" version="1.0" encoding="UTF-8"
		indent="yes" />
	<xsl:decimal-format name="euro" decimal-separator=","
		grouping-separator="." NaN="" minus-sign="-" zero-digit="0" />
	<xsl:template match="/">
		<html>
			<head>
				<title>WBV 2016-97-1</title>
				<style type="text/css">
					h1 { font-family:Arial,sans-serif; font-size:18px;
					font-weight:bold;}
					p { font-family:Arial,sans-serif; font-size:10px;
					font-weight:normal;}
					p.fett { font-family:Arial,sans-serif;
					font-size:10px; font-weight:bold;}
					table {border: 0;
					font-family:Arial,sans-serif;border-collapse:
					collapse;border-color: #000000;}
					tr {font-family:Arial,sans-serif;
					font-size:8px; font-weight:normal; border-bottom-style:solid;
					border-bottom-width:1px;}
					td.werte {font-family:Arial,sans-serif;
					font-size:8px; font-weight:normal; text-align:right;
					border-left-width: 1px; border-right-width: 1px; border-top-width:
					1px; border-bottom-style: solid; border-bottom-width: 1px;}
					td.werteborderleft {font-family:Arial,sans-serif; font-size:8px;
					font-weight:normal; text-align:right; border-left: 1pt solid;
					border-right-width: 1px; border-top-width: 1px;
					border-bottom-style: solid; border-bottom-width: 1px;}
					th.werte
					{font-family:Arial,sans-serif; font-size:8px; font-weight:bold;
					text-align:right;}
					td.bez {font-family:Arial,sans-serif;
					font-size:8px; font-weight:normal; text-align:left;
					border-left-width: 1px; border-right-width: 1px; border-top-width:
					1px; border-bottom-style: solid; border-bottom-width: 1px;}
					td.bezgruppe {font-family:Arial,sans-serif; font-size:8px;
					font-weight:normal; text-align:left; border-left-width: 1px;
					border-right-width: 1px; border-top-width: 1px;
					border-bottom-style: solid; border-bottom-width: 1px;}
				</style>
			</head>
			<body>
				<xsl:apply-templates />
			</body>
		</html>
	</xsl:template>
	<!-- -->
	<xsl:template name="formatNegNumber">
		<xsl:param name="val" />
		<xsl:if test="$val &lt; 0">
			<xsl:attribute name="style"><xsl:text>color:red</xsl:text></xsl:attribute>
		</xsl:if>
	</xsl:template>
	<!-- -->
	<xsl:template match="wb:wbv2016_97_1">
		<h1 class="h1">
			<xsl:text>Wissensbilanz</xsl:text>
		</h1>
		<table class="table">
			<tbody>
				<tr>
					<td>
						<xsl:text>Version: </xsl:text>
					</td>
					<td>
						<xsl:value-of select="version" />
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>Stichtag-Jahr: </xsl:text>
					</td>
					<td>
						<xsl:value-of select="stichtagjahr" />
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>Kennzeichen: </xsl:text>
					</td>
					<td>
						<xsl:value-of select="kennzeichen" />
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>Universität: </xsl:text>
					</td>
					<td>
						<xsl:value-of select="universitaet/univname" />
						<xsl:text> (</xsl:text>
						<xsl:value-of select="universitaet/univkode" />
						<xsl:text>)</xsl:text>
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>Lieferdatum: </xsl:text>
					</td>
					<td>
						<xsl:value-of select="lieferdaten/lieferdatum" />
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>Lieferzeit: </xsl:text>
					</td>
					<td>
						<xsl:value-of select="lieferdaten/lieferzeit" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:apply-templates select="wb_1 | wb_2 | wb_3 | wb_4 | db_5 | wb_9" />
	</xsl:template>
	<!-- Template gibt die Kopfdaten pro Kennzahl aus -->
	<xsl:template name="printKZKopf">
		<xsl:variable name="kzidf" select="name" />
		<p class="p">
			<xsl:value-of
				select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxwbkennz.xml')//KZKODE[../KZIDF = $kzidf]" />
		</p>
		<p class="fett">
			<xsl:value-of
				select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxwbkennz.xml')//KZBEZ[../KZIDF = $kzidf]" />
		</p>
	</xsl:template>
	<!-- Template gibt die Interpretation pro Kennzahl aus -->
	<xsl:template name="printInterpret">
		<p class="p">
			<xsl:copy-of select="interpretation" />
		</p>
	</xsl:template>
	<!-- -->
	<xsl:template match="wb_1 | wb_2 | wb_3 | wb_4 | db_5">
		<xsl:apply-templates select="*[name() != 'name']" />
	</xsl:template>
	<!-- Leere Kennzahlen (nicht originär) 1.A.1, 2.A.3, 2.A.5, 2.A.6, 2.A.7,
		2.A.8, 2.A.9, 2.A.10, 3.A.1, 3.A.2, 3.A.3 -->
	<xsl:template
		match="wb_1_A_1 | wb_2_A_3 | wb_2_AM_3 | wb_2_A_5 | wb_2_A_6 | wb_2_A_7 | wb_2_A_8 | wb_2_A_9 | wb_3_A_1 | wb_3_A_2 | wb_3_A_3">
		<xsl:call-template name="printKZKopf" />
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 1.AM.1, 9.13 -->
	<xsl:template match="wb_1_AM_1 | wb_9013">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th />
					<th colspan="3">Köpfe</th>
					<th colspan="3">Vollzeitäquivalente</th>
				</tr>
				<tr class="tr">
					<th width="80" align="left">Personalkategorie</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:for-each select="descendant::personalzeile">
					<xsl:sort select="personalkategorie" data-type="number"
						order="ascending" />
					<xsl:variable name="personalkategorie" select="personalkategorie" />
					<tr class="tr">
						<td class="bez">
							<xsl:choose>
								<xsl:when test="ancestor::wb_1_AM_1">
									<xsl:value-of
										select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'PERSONALKATEGORIE6_AV' and ../RV_LOW_VALUE = $personalkategorie]" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of
										select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'PERSONALKATEGORIE7_AV' and ../RV_LOW_VALUE = $personalkategorie]" />
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@frauen), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@maenner), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@gesamt), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(vollzeitaequivalente/@frauen), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(vollzeitaequivalente/@maenner), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(vollzeitaequivalente/@gesamt), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
				<tr class="tr">
					<td class="bezgruppe">Insgesamt</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen[../personalkategorie=1 or ../personalkategorie=8]/@frauen)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen[../personalkategorie=1 or ../personalkategorie=8]/@maenner)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen[../personalkategorie=1 or ../personalkategorie=8]/@gesamt)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::vollzeitaequivalente[../personalkategorie=1 or ../personalkategorie=8]/@frauen)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::vollzeitaequivalente[../personalkategorie=1 or ../personalkategorie=8]/@maenner)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::vollzeitaequivalente[../personalkategorie=1 or ../personalkategorie=8]/@gesamt)), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>

	<!-- 1.A.2, 1.AM.2 -->
	<xsl:template match="wb_1_A_2 | wb_1_AM_2">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th />
					<th colspan="12" align="center">Berufungsart</th>
				</tr>
				<tr class="tr">
					<th />
					<th colspan="3" align="center">
						<xsl:value-of
							select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN='BERUFUNGSART_AV' and ../RV_LOW_VALUE=1]" />
					</th>
					<th colspan="3" align="center">
						<xsl:value-of
							select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN='BERUFUNGSART_AV' and ../RV_LOW_VALUE=2]" />
					</th>
					<th colspan="3" align="center">
						<xsl:value-of
							select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN='BERUFUNGSART_AV' and ../RV_LOW_VALUE=3]" />
					</th>
					<th colspan="3" align="center">Gesamt</th>
				</tr>
				<tr class="tr">
					<th width="350" align="left">Wissenschafts-/Kunstzweig</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:variable name="zweige" select="descendant::berufungzeile/zweig" />
				<xsl:for-each select="$zweige">
					<xsl:sort select="substring(., 1, 1)" order="ascending" />
					<xsl:sort select="." order="ascending" />
					<xsl:variable name="zweig" select="." />
					<xsl:if test="generate-id() = generate-id($zweige[. = current()][1])">
						<tr class="tr">
							<td class="bez">
								<xsl:value-of select="$zweig" />
								<xsl:text> </xsl:text>
								<xsl:value-of
									select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxwikuzw2014.xml')//WISSZWTEXT[../WISSZWCODE = $zweig]" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../zweig=$zweig and ../berufungsart=1]/@frauen)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../zweig=$zweig and ../berufungsart=1]/@maenner)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../zweig=$zweig and ../berufungsart=1]/@gesamt)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../zweig=$zweig and ../berufungsart=2]/@frauen)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../zweig=$zweig and ../berufungsart=2]/@maenner)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../zweig=$zweig and ../berufungsart=2]/@gesamt)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../zweig=$zweig and ../berufungsart=3]/@frauen)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../zweig=$zweig and ../berufungsart=3]/@maenner)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../zweig=$zweig and ../berufungsart=3]/@gesamt)), '#.##0,00', 'euro')" />
							</td>

							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../zweig=$zweig]/@frauen)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../zweig=$zweig]/@maenner)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../zweig=$zweig]/@gesamt)), '#.##0,00', 'euro')" />
							</td>
						</tr>
					</xsl:if>
				</xsl:for-each>
				<tr class="tr">
					<td class="bez" style="padding-left: 200;">
						Herkunftsuniversität/
						<br />
						vorherige Dienstgeberin oder
						<br />
						vorheriger Dienstgeber
					</td>
					<td colspan="12" />
				</tr>
				<xsl:variable name="herkuenfte" select="descendant::berufungzeile/herkunft" />
				<xsl:for-each select="$herkuenfte">
					<xsl:sort select="." order="ascending" />
					<xsl:variable name="herkunft" select="." />
					<xsl:if
						test="generate-id() = generate-id($herkuenfte[. = current()][1])">
						<tr class="tr">
							<td class="bez" style="padding-left:200;">
								<xsl:value-of
									select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN='HERKUNFT_AV' and ../RV_LOW_VALUE=$herkunft]" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../herkunft=$herkunft and ../berufungsart=1]/@frauen)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../herkunft=$herkunft and ../berufungsart=1]/@maenner)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../herkunft=$herkunft and ../berufungsart=1]/@gesamt)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../herkunft=$herkunft and ../berufungsart=2]/@frauen)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../herkunft=$herkunft and ../berufungsart=2]/@maenner)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../herkunft=$herkunft and ../berufungsart=2]/@gesamt)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../herkunft=$herkunft and ../berufungsart=3]/@frauen)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../herkunft=$herkunft and ../berufungsart=3]/@maenner)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../herkunft=$herkunft and ../berufungsart=3]/@gesamt)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../herkunft=$herkunft]/@frauen)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../herkunft=$herkunft]/@maenner)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../..//anzahlen[../herkunft=$herkunft]/@gesamt)), '#.##0,00', 'euro')" />
							</td>
						</tr>
					</xsl:if>
				</xsl:for-each>
				<tr class="tr">
					<td class="bez" style="padding-left:200;">Gesamt</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(daten//anzahlen[../berufungsart=1]/@frauen)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(daten//anzahlen[../berufungsart=1]/@maenner)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(daten//anzahlen[../berufungsart=1]/@gesamt)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(daten//anzahlen[../berufungsart=2]/@frauen)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(daten//anzahlen[../berufungsart=2]/@maenner)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(daten//anzahlen[../berufungsart=2]/@gesamt)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(daten//anzahlen[../berufungsart=3]/@frauen)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(daten//anzahlen[../berufungsart=3]/@maenner)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(daten//anzahlen[../berufungsart=3]/@gesamt)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(daten//anzahlen/@frauen)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(daten//anzahlen/@maenner)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(daten//anzahlen/@gesamt)), '#.##0,00', 'euro')" />
					</td>
				</tr>

			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 1.A.3 -->
	<xsl:template match="wb_1_A_3">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<thead>
				<tr class="tr">
					<th />
					<th align="center" colspan="3">Kopfzahlen</th>
					<th align="center" colspan="2">Anteile in %</th>
					<th align="center" colspan="2">Frauenquoten-Erfüllungsgrad</th>
				</tr>
				<tr class="tr">
					<th width="80" align="left">Monitoring-Kategorie</th>
					<th width="0" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="100" align="werte">Organe mit erfüllter Quote</th>
					<th width="100" align="werte">Organe gesamt</th>
				</tr>
			</thead>
			<tbody>
				<xsl:for-each select="descendant::quotenzeile">
					<xsl:sort select="monitoringkategorie" order="ascending"
						data-type="number" />
					<xsl:variable name="monitoringkategorie" select="monitoringkategorie" />
					<tr class="tr">
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'MONITORINGKATEGORIE_AV' and ../RV_LOW_VALUE = $monitoringkategorie]" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@frauen), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@maenner), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@gesamt), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anteile/@frauen), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anteile/@maenner), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(organanzahlmitquote), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(organanzahl), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 1.A.4 -->
	<xsl:template match="wb_1_A_4">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr" style="border: 0;">
					<th width="80" align="left" rowspan="2">Personalkategorie</th>
					<th colspan="3">Kopfzahlen</th>
					<th width="50" rowspan="2">
						Gender pay gap
						<br />
						Frauenlöhne entsprechen ...% der Männerlöhne
					</th>
				</tr>
				<tr class="tr">
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:for-each select="descendant::lohnzeile">
					<xsl:sort select="personalkategorie1" order="ascending" />
					<xsl:variable name="personalkategorie1" select="personalkategorie1" />
					<tr class="tr">
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'PERSONALKATEGORIE1_AV' and ../RV_LOW_VALUE = $personalkategorie1]" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@frauen), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@maenner), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@gesamt), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:choose>
								<xsl:when test="genderpaygap = -1">
									<xsl:text>n.a.</xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of
										select="format-number(number(genderpaygap), '#.##0,00', 'euro')" />
								</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>

	<!-- 1.A.5 -->
	<xsl:template match="wb_1_A_5">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="60%"></th>
					<th colspan="4" align="center">Anzahl</th>
				</tr>
				<tr class="tr">
					<td class="bez">Verfahren gemäß § 98 UG, die zum Dienstantritt eines
						Professorin / eines Professors geführt haben</td>
					<td colspan="4" align="center">
						<xsl:value-of
							select="format-number(number(descendant::prozessschrittZeile[prozessschritt='8']/anzahlen/@gesamt), '#0', 'euro')" />
					</td>
				</tr>
				<tr class="tr">
					<td class="bez">Prozessschritte</td>
					<td align="center" style="border-right: 2px solid;">
						Ø Frauen-
						<br />
						anteil in %
					</td>
					<td colspan="3" align="center">Kopfzahlen</td>
				</tr>
				<tr class="tr">
					<td colspan="2" style="border-right: 2px solid;" />
					<td align="center">Frauen</td>
					<td align="center">Männer</td>
					<td align="center">Gesamt</td>
				</tr>

				<xsl:for-each select="descendant::prozessschrittZeile">
					<xsl:sort select="prozessschritt" order="ascending" />
					<xsl:variable name="prozessschritt" select="prozessschritt" />
					<tr class="tr">
						<xsl:if test="$prozessschritt=2">
							<xsl:attribute name="style">border-bottom: 2px solid;</xsl:attribute>
						</xsl:if>
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'PROZESSSCHRITT_AV' and ../RV_LOW_VALUE = $prozessschritt]" />
						</td>
						<td class="werte" style="border-right: 2px solid;">
							<xsl:value-of
								select="format-number(number(frauenanteil), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@frauen), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@maenner), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@gesamt), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>

				<tr class="tr" style="border-top: 2px solid;">
					<td />
					<td colspan="4" align="center">
						Chancenindikator
						<br />
						(1= Chancen-Gleichheit)
					</td>
				</tr>

				<tr class="tr">
					<td class="bez">Selektionschance für Frauen – Hearing</td>
					<td class="werte" colspan="4">
						<xsl:value-of
							select="format-number(number(descendant::prozessschrittZeile[prozessschritt=6]/chancenindikator), '#.##0,00', 'euro')" />
					</td>
				</tr>
				<tr class="tr">
					<td class="bez">Selektionschance für Frauen – Berufungsvorschlag</td>
					<td class="werte" colspan="4">
						<xsl:value-of
							select="format-number(number(descendant::prozessschrittZeile[prozessschritt=7]/chancenindikator), '#.##0,00', 'euro')" />
					</td>
				</tr>
				<tr class="tr">
					<td class="bez">Berufungschance für Frauen</td>
					<td class="werte" colspan="4">
						<xsl:value-of
							select="format-number(number(descendant::prozessschrittZeile[prozessschritt=8]/chancenindikator), '#.##0,00', 'euro')" />
					</td>
				</tr>

			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>

	<!-- 1.B.1 -->
	<xsl:template match="wb_1_B_1">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="80" align="left">Aufenthaltsdauer</th>
					<th width="80" align="left">Gastlandkategorie</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:call-template name="printAufenthaltsdauerRow">
					<xsl:with-param name="aufenthaltsdauer" select="3" />
				</xsl:call-template>
				<xsl:call-template name="printAufenthaltsdauerRow">
					<xsl:with-param name="aufenthaltsdauer" select="1" />
				</xsl:call-template>
				<xsl:call-template name="printAufenthaltsdauerRow">
					<xsl:with-param name="aufenthaltsdauer" select="2" />
				</xsl:call-template>

				<tr class="tr">
					<td class="bez" rowspan="3">Insgesamt</td>
					<td class="bez">EU</td>
					<td class="werte">
						<xsl:value-of
							select="sum(descendant::auslandzeile/anzahlen[../gastland=3]/@frauen)" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="sum(descendant::auslandzeile/anzahlen[../gastland=3]/@maenner)" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="sum(descendant::auslandzeile/anzahlen[../gastland=3]/@gesamt)" />
					</td>
				</tr>
				<tr class="tr">
					<td class="bez">Drittstaaten</td>
					<td class="werte">
						<xsl:value-of
							select="sum(descendant::auslandzeile/anzahlen[../gastland=4]/@frauen)" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="sum(descendant::auslandzeile/anzahlen[../gastland=4]/@maenner)" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="sum(descendant::auslandzeile/anzahlen[../gastland=4]/@gesamt)" />
					</td>
				</tr>
				<tr class="tr">
					<td class="bez">Gesamt</td>
					<td class="werte">
						<xsl:value-of
							select="sum(descendant::auslandzeile/anzahlen[../gastland!=0]/@frauen)" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="sum(descendant::auslandzeile/anzahlen[../gastland!=0]/@maenner)" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="sum(descendant::auslandzeile/anzahlen[../gastland!=0]/@gesamt)" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>

	<xsl:template name="printAufenthaltsdauerRow">
		<xsl:param name="aufenthaltsdauer" />
		<tr class="tr">
			<td class="bez" rowspan="3">
				<xsl:value-of
					select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN='AUFENTHALTSDAUER_AV' and ../RV_LOW_VALUE=$aufenthaltsdauer]" />
			</td>
			<td class="bez">EU</td>
			<td class="werte">
				<xsl:value-of
					select="sum(descendant::auslandzeile/anzahlen[../aufenthaltsdauer=$aufenthaltsdauer and ../gastland=3]/@frauen)" />
			</td>
			<td class="werte">
				<xsl:value-of
					select="sum(descendant::auslandzeile/anzahlen[../aufenthaltsdauer=$aufenthaltsdauer and ../gastland=3]/@maenner)" />
			</td>
			<td class="werte">
				<xsl:value-of
					select="sum(descendant::auslandzeile/anzahlen[../aufenthaltsdauer=$aufenthaltsdauer and ../gastland=3]/@gesamt)" />
			</td>
		</tr>
		<tr class="tr">
			<td class="bez">Drittstaaten</td>
			<td class="werte">
				<xsl:value-of
					select="sum(descendant::auslandzeile/anzahlen[../aufenthaltsdauer=$aufenthaltsdauer and ../gastland=4]/@frauen)" />
			</td>
			<td class="werte">
				<xsl:value-of
					select="sum(descendant::auslandzeile/anzahlen[../aufenthaltsdauer=$aufenthaltsdauer and ../gastland=4]/@maenner)" />
			</td>
			<td class="werte">
				<xsl:value-of
					select="sum(descendant::auslandzeile/anzahlen[../aufenthaltsdauer=$aufenthaltsdauer and ../gastland=4]/@gesamt)" />
			</td>
		</tr>
		<tr class="tr">
			<td class="bez">Gesamt</td>
			<td class="werte">
				<xsl:value-of
					select="sum(descendant::auslandzeile/anzahlen[../aufenthaltsdauer=$aufenthaltsdauer and ../gastland!=0]/@frauen)" />
			</td>
			<td class="werte">
				<xsl:value-of
					select="sum(descendant::auslandzeile/anzahlen[../aufenthaltsdauer=$aufenthaltsdauer and ../gastland!=0]/@maenner)" />
			</td>
			<td class="werte">
				<xsl:value-of
					select="sum(descendant::auslandzeile/anzahlen[../aufenthaltsdauer=$aufenthaltsdauer and ../gastland!=0]/@gesamt)" />
			</td>
		</tr>
	</xsl:template>

	<!-- Einzeilige Reports 5.2.1, 9.11 -->
	<xsl:template match="db_5_2_1 | wb_9011">
		<xsl:variable name="kzidf" select="name" />
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="500" align="left" />
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<tr class="tr">
					<td class="bez">
						<xsl:value-of
							select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxwbkennz.xml')//KZBEZ[../KZIDF = $kzidf]" />
					</td>
					<td class="werte">
						<xsl:choose>
							<xsl:when test="daten/betrag">
								<xsl:value-of
									select="format-number(number(daten/betrag), '#.##0,00', 'euro')" />
							</xsl:when>
							<xsl:when test="daten/anzahl">
								<xsl:value-of
									select="format-number(number(daten/anzahl), '#.##0,00', 'euro')" />
							</xsl:when>
							<xsl:when test="daten/flaeche">
								<xsl:value-of
									select="format-number(number(daten/flaeche), '#.##0,00', 'euro')" />
							</xsl:when>
						</xsl:choose>
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>

	<!-- 5.1.3 -->
	<xsl:template match="db_5_1_3">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr" style="border-bottom: 0px solid;">
					<th width="200" align="left" rowspan="2">Spendengeber</th>
					<th width="100" colspan="4">Sitz der Spendengeber</th>
				</tr>
				<tr class="tr">
					<th width="50">national</th>
					<th width="50">sonstige</th>
					<th width="50">Drittstaaten</th>
					<th width="50">Gesamt</th>
				</tr>
				<xsl:variable name="spendengeberListe" select="descendant::spendenzeile/geber" />
				<xsl:for-each select="$spendengeberListe">
					<xsl:sort select="." data-type="number" order="ascending" />
					<xsl:variable name="spendengeber" select="." />
					<xsl:if
						test="generate-id() = generate-id($spendengeberListe[. = current()][1])">
						<tr class="tr">
							<td class="bez">
								<xsl:value-of
									select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'SPENDENGEBER_AV' and ../RV_LOW_VALUE=$spendengeber]" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(../..//betrag[../geber=$spendengeber and ../herkunft=1], '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(../..//betrag[../geber=$spendengeber and ../herkunft=2], '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(../..//betrag[../geber=$spendengeber and ../herkunft=3], '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(sum(../..//betrag[../geber=$spendengeber]), '#.##0,00', 'euro')" />
							</td>
						</tr>
					</xsl:if>
				</xsl:for-each>
				<tr class="tr">
					<td class="bez">Insgesamt</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(sum(.//betrag[../herkunft=1]), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(sum(.//betrag[../herkunft=2]), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(sum(.//betrag[../herkunft=3]), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of select="format-number(sum(.//betrag), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>

	<!-- 2.A.1 -->
	<xsl:template match="wb_2_A_1">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th />
					<th align="center" colspan="5">Verwendung</th>
				</tr>
				<tr class="tr">
					<th width="350" align="left">Curriculum</th>
					<th class="werte">
						<xsl:value-of
							select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'PERSONALKATEGORIE4_AV' and ../RV_LOW_VALUE = '1']" />
					</th>
					<th class="werte">
						<xsl:value-of
							select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'PERSONALKATEGORIE4_AV' and ../RV_LOW_VALUE = '2']" />
					</th>
					<th class="werte">
						<xsl:value-of
							select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'PERSONALKATEGORIE4_AV' and ../RV_LOW_VALUE = '3']" />
					</th>
					<th class="werte">
						<xsl:value-of
							select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'PERSONALKATEGORIE4_AV' and ../RV_LOW_VALUE = '5']" />
					</th>
				</tr>
				<xsl:variable name="isceds" select="descendant::zeitzeile/isced3" />
				<xsl:for-each select="$isceds">
					<xsl:sort select="." order="ascending" />
					<xsl:variable name="isced" select="." />
					<xsl:if test="generate-id() = generate-id($isceds[. = current()][1]) and $isced != 900">
						<tr class="tr">
							<td class="bez">
								<xsl:value-of select="$isced" />
								<xsl:text> </xsl:text>
								<xsl:value-of
									select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxisced3.xml')//ISCEDBEZ_DT[../ISCEDKODE = $isced]" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../zeitzeile[isced3=$isced and personalkategorie='1']/vollzeitaequivalent), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../zeitzeile[isced3=$isced and personalkategorie='2']/vollzeitaequivalent), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../zeitzeile[isced3=$isced and personalkategorie='3']/vollzeitaequivalent), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../zeitzeile[isced3=$isced and personalkategorie='5']/vollzeitaequivalent), '#.##0,00', 'euro')" />
							</td>
						</tr>
					</xsl:if>
				</xsl:for-each>
				<tr class="tr">
					<td class="bezgruppe">Insgesamt</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::vollzeitaequivalent[../personalkategorie='1' and ../isced3!=900])), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::vollzeitaequivalent[../personalkategorie='2' and ../isced3!=900])), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::vollzeitaequivalent[../personalkategorie='3' and ../isced3!=900])), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::vollzeitaequivalent[../personalkategorie='5' and ../isced3!=900])), '#.##0,00', 'euro')" />
					</td>
				</tr>
				<tr class="tr">
					<td class="bezgruppe"><xsl:value-of
									select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxisced3.xml')//ISCEDBEZ_DT[../ISCEDKODE = 900]" /></td>
					<td class="werte" colspan="4">
						<xsl:value-of
							select="format-number(number(descendant::vollzeitaequivalent[../personalkategorie='5' and ../isced3=900]), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 2.A.2 -->
	<xsl:template match="wb_2_A_2">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr" style="border-bottom: 0px solid;">
					<th width="500" align="left" />
					<th align="center" colspan="7" style="border-right: 1px solid;">Studienform</th>
					<th align="center" rowspan="2">internationale Joint Degree/ Double
						Degree/Multiple Degree-Programme</th>
					<th align="center" rowspan="2">nationale Studienkooperationen
						(gemeinsame Einrichtungen)</th>
				</tr>
				<tr class="tr">
					<th>Studienart</th>
					<th>Präsenzstudien</th>
					<th>davon zur Gänze englischsprachig studierbar</th>
					<th>davon berufsbegleitend studierbar</th>
					<th>Fernstudien</th>
					<th>davon zur Gänze englischsprachig studierbar</th>
					<th>davon berufsbegleitend studierbar</th>
					<th style="border-right: 1px solid;">Gesamt</th>
				</tr>
				<xsl:variable name="studienarten"
					select="descendant::studienzeile/studienart" />
				<xsl:for-each select="$studienarten">
					<xsl:sort select="." data-type="number" order="ascending" />
					<xsl:variable name="studienart" select="." />
					<xsl:if
						test="generate-id() = generate-id($studienarten[. = current()][1])">
						<tr class="tr">
							<td class="bez">
								<xsl:value-of
									select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN='STUDIENART_AV' and ../RV_LOW_VALUE=$studienart]" />
							</td>
							<!-- Präsenzstudien -->
							<td class="werte">
								<xsl:value-of
									select="format-number(../..//anzahl[../studienart=$studienart and ../studienform=1], '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(../..//anzahl[../studienart=$studienart and ../studienform=14], '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(../..//anzahl[../studienart=$studienart and ../studienform=15], '#.##0,00', 'euro')" />
							</td>
							<!-- Fernstudien -->
							<td class="werte">
								<xsl:value-of
									select="format-number(../..//anzahl[../studienart=$studienart and ../studienform=3], '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(../..//anzahl[../studienart=$studienart and ../studienform=16], '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(../..//anzahl[../studienart=$studienart and ../studienform=17], '#.##0,00', 'euro')" />
							</td>
							<!-- Gesamt -->
							<td class="werte" style="border-right: 1px solid;">
								<xsl:value-of
									select="format-number(sum(../..//anzahl[../studienart=$studienart and (../studienform=1 or ../studienform=3)]), '#.##0,00', 'euro')" />
							</td>
							<!-- Kooperationen -->
							<td class="werte">
								<xsl:value-of
									select="format-number(../..//anzahl[../studienart=$studienart and ../studienform=5], '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(../..//anzahl[../studienart=$studienart and ../studienform=6], '#.##0,00', 'euro')" />
							</td>
						</tr>
					</xsl:if>
				</xsl:for-each>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>

	<!-- 2.B.1, 2.BM.1 -->
	<xsl:template match="wb_2_B_1 | wb_2_BM_1">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr" style="border-bottom: 0px solid;">
					<th width="350" align="left" rowspan="3">Ausbildungsstruktur</th>
					<th align="center" colspan="12">Staatsangehörigkeit</th>
				</tr>
				<tr class="tr" style="border-bottom: 0px solid;">
					<th align="center" colspan="3">
						<xsl:value-of
							select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'STAATSANGEHOERIGKEIT_AV' and ../RV_LOW_VALUE = 2]" />
					</th>
					<th align="center" colspan="3">
						<xsl:value-of
							select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'STAATSANGEHOERIGKEIT_AV' and ../RV_LOW_VALUE = 3]" />
					</th>
					<th align="center" colspan="3">
						<xsl:value-of
							select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'STAATSANGEHOERIGKEIT_AV' and ../RV_LOW_VALUE = 4]" />
					</th>
					<th align="center" colspan="3">Gesamt</th>
				</tr>
				<tr class="tr">
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:variable name="beschaeftigung"
					select="descendant::beschaeftigungszeile/personalkategorie" />
				<xsl:for-each select="$beschaeftigung">
					<xsl:sort select="." order="ascending" />
					<xsl:variable name="personalkategorie" select="." />
					<xsl:if
						test="generate-id() = generate-id($beschaeftigung[. = current()][1])">
						<tr class="tr">
							<td class="bez">
								<xsl:value-of
									select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'PERSONALKATEGORIE2_AV' and ../RV_LOW_VALUE = $personalkategorie]" />
							</td>

							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../beschaeftigungszeile[personalkategorie=$personalkategorie and staatsangehoerigkeit=2]/anzahlen/@frauen), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../beschaeftigungszeile[personalkategorie=$personalkategorie and staatsangehoerigkeit=2]/anzahlen/@maenner), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../beschaeftigungszeile[personalkategorie=$personalkategorie and staatsangehoerigkeit=2]/anzahlen/@gesamt), '#.##0,00', 'euro')" />
							</td>

							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../beschaeftigungszeile[personalkategorie=$personalkategorie and staatsangehoerigkeit=3]/anzahlen/@frauen), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../beschaeftigungszeile[personalkategorie=$personalkategorie and staatsangehoerigkeit=3]/anzahlen/@maenner), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../beschaeftigungszeile[personalkategorie=$personalkategorie and staatsangehoerigkeit=3]/anzahlen/@gesamt), '#.##0,00', 'euro')" />
							</td>

							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../beschaeftigungszeile[personalkategorie=$personalkategorie and staatsangehoerigkeit=4]/anzahlen/@frauen), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../beschaeftigungszeile[personalkategorie=$personalkategorie and staatsangehoerigkeit=4]/anzahlen/@maenner), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../beschaeftigungszeile[personalkategorie=$personalkategorie and staatsangehoerigkeit=4]/anzahlen/@gesamt), '#.##0,00', 'euro')" />
							</td>

							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../../beschaeftigungszeile[personalkategorie=$personalkategorie]/anzahlen/@frauen)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../../beschaeftigungszeile[personalkategorie=$personalkategorie]/anzahlen/@maenner)), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../../beschaeftigungszeile[personalkategorie=$personalkategorie]/anzahlen/@gesamt)), '#.##0,00', 'euro')" />
							</td>

						</tr>
					</xsl:if>
				</xsl:for-each>
				<tr class="tr">
					<td class="bezgruppe">Insgesamt</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen[../staatsangehoerigkeit=2]/@frauen)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen[../staatsangehoerigkeit=2]/@maenner)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen[../staatsangehoerigkeit=2]/@gesamt)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen[../staatsangehoerigkeit=3]/@frauen)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen[../staatsangehoerigkeit=3]/@maenner)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen[../staatsangehoerigkeit=3]/@gesamt)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen[../staatsangehoerigkeit=4]/@frauen)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen[../staatsangehoerigkeit=4]/@maenner)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen[../staatsangehoerigkeit=4]/@gesamt)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen/@frauen)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen/@maenner)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen/@gesamt)), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>

	<!-- 3.B.1 -->
	<xsl:template match="wb_3_B_1">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="350" align="left">Wissenschafts-/Kunstzweig</th>
					<th width="300" align="left">Typ von Publikationen</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:for-each select="descendant::publikationzeile">
					<xsl:sort select="substring(zweig, 1, 1)" order="ascending" />
					<xsl:sort select="zweig" order="ascending" />
					<xsl:sort select="publikation" order="ascending" />
					<xsl:variable name="zweig" select="zweig" />
					<xsl:variable name="publikation" select="publikation" />
					<tr class="tr">
						<td class="bez">
							<xsl:value-of select="zweig" />
							<xsl:text> </xsl:text>
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxwikuzw2014.xml')//WISSZWTEXT[../WISSZWCODE = $zweig]" />
						</td>
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'PUBLIKATIONSTYP_AV' and ../RV_LOW_VALUE = $publikation]" />
						</td>
						<td class="werte">
							<xsl:value-of select="format-number(number(anzahl), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
				<tr class="tr">
					<td class="bezgruppe">Insgesamt</td>
					<td class="bez" />
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahl)), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 3.B.2 -->
	<xsl:template match="wb_3_B_2">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="350" align="left">Wissenschafts-/Kunstzweig</th>
					<th width="150" align="left">Veranstaltungs-Typus</th>
					<th width="150" align="left">Vortrags-Typus</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:for-each select="descendant::vortragzeile">
					<xsl:sort select="substring(zweig, 1, 1)" order="ascending" />
					<xsl:sort select="zweig" order="ascending" />
					<xsl:sort select="veranstaltung" order="ascending" />
					<xsl:sort select="vortrag" order="ascending" />
					<xsl:variable name="zweig" select="zweig" />
					<xsl:variable name="veranstaltung" select="veranstaltung" />
					<xsl:variable name="vortrag" select="vortrag" />
					<tr class="tr">
						<td class="bez">
							<xsl:value-of select="zweig" />
							<xsl:text> </xsl:text>
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxwikuzw2014.xml')//WISSZWTEXT[../WISSZWCODE = $zweig]" />
						</td>
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'VERANSTALTUNG_AV' and ../RV_LOW_VALUE = $veranstaltung]" />
						</td>
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'VORTRAG_AV' and ../RV_LOW_VALUE = $vortrag]" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@frauen), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@maenner), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@gesamt), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
				<tr class="tr">
					<td class="bezgruppe">Insgesamt</td>
					<td class="bez" />
					<td class="bez" />
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen/@frauen)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen/@maenner)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen/@gesamt)), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>

	<!-- 3.BM.1 -->
	<xsl:template match="wb_3_BM_1">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="350" align="left">Wissenschafts-/Kunstzweig</th>
					<th width="300" align="left">Typ von Publikationen</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:for-each select="descendant::publikationzeile">
					<xsl:sort select="substring(zweig, 1, 1)" order="ascending" />
					<xsl:sort select="zweig" order="ascending" />
					<xsl:sort select="publikation" order="ascending" />
					<xsl:variable name="zweig" select="zweig" />
					<xsl:variable name="publikation" select="publikation" />
					<tr class="tr">
						<td class="bez">
							<xsl:value-of select="zweig" />
							<xsl:text> </xsl:text>
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxwikuzw2014.xml')//WISSZWTEXT[../WISSZWCODE = $zweig]" />
						</td>
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'PUBLIKATIONSTYP_AV' and ../RV_LOW_VALUE = $publikation]" />
						</td>
						<td class="werte">
							<xsl:value-of select="format-number(number(anzahl), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
				<tr class="tr">
					<td class="bezgruppe">Insgesamt</td>
					<td class="bez" />
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahl)), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>

	<!-- 3.BM.2 -->
	<xsl:template match="wb_3_BM_2">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="350" align="left">Wissenschafts-/Kunstzweig</th>
					<th width="150" align="left">Veranstaltungs-Typus</th>
					<th width="150" align="left">Vortrags-Typus</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:for-each select="descendant::vortragzeile">
					<xsl:sort select="substring(zweig, 1, 1)" order="ascending" />
					<xsl:sort select="zweig" order="ascending" />
					<xsl:sort select="veranstaltung" order="ascending" />
					<xsl:sort select="vortrag" order="ascending" />
					<xsl:variable name="zweig" select="zweig" />
					<xsl:variable name="veranstaltung" select="veranstaltung" />
					<xsl:variable name="vortrag" select="vortrag" />
					<tr class="tr">
						<td class="bez">
							<xsl:value-of select="zweig" />
							<xsl:text> </xsl:text>
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxwikuzw2014.xml')//WISSZWTEXT[../WISSZWCODE = $zweig]" />
						</td>
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'VERANSTALTUNG_AV' and ../RV_LOW_VALUE = $veranstaltung]" />
						</td>
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'VORTRAG_AV' and ../RV_LOW_VALUE = $vortrag]" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@frauen), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@maenner), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@gesamt), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
				<tr class="tr">
					<td class="bezgruppe">Insgesamt</td>
					<td class="bez" />
					<td class="bez" />
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen/@frauen)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen/@maenner)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen/@gesamt)), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 3.B.3, 3.BM.3 -->
	<xsl:template match="wb_3_B_3 | wb_3_BM_3">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="350" align="left">Zählkategorie</th>
					<th width="50" class="werte">Anzahl</th>
				</tr>
				<xsl:for-each select="descendant::patentzeile">
					<xsl:sort select="patentanzahl" order="ascending"
						data-type="number" />
					<xsl:variable name="patentanzahl" select="patentanzahl" />
					<tr class="tr">
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'PATENTANZAHL_AV' and ../RV_LOW_VALUE = $patentanzahl]" />
						</td>
						<td class="werte">
							<xsl:choose>
								<xsl:when test="patentanzahl > 12 and anzahl = 99">
									<xsl:text>n.a.</xsl:text>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of
										select="format-number(number(anzahl), '#.##0,00', 'euro')" />
								</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>

	<!-- 1.C.1, 1.CM.1 -->
	<xsl:template match="wb_1_C_1 | wb_1_CM_1">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th colspan="2" />
					<th colspan="4">Sitz der Auftrag-/Fördergeber-Organisation</th>
				</tr>
				<tr class="tr">
					<th colspan="2" width="350" align="left">Wissenschafts-/Kunstzweig</th>
					<th width="50">national</th>
					<th width="50">EU</th>
					<th width="50">Drittstaaten</th>
					<th width="50">Gesamt</th>
				</tr>
				<xsl:variable name="zweige" select="descendant::einnahmenzeile/zweig" />
				<xsl:for-each select="$zweige">
					<xsl:sort select="." data-type="number" order="ascending" />
					<xsl:variable name="zweig" select="." />
					<xsl:if test="generate-id() = generate-id($zweige[. = current()][1])">
						<tr class="tr">
							<td class="bez" colspan="2">
								<xsl:value-of
									select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxwikuzw2014.xml')//WISSZWTEXT[../WISSZWCODE = $zweig]" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(sum(../..//betrag[../zweig=$zweig and ../herkunft=2]), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(sum(../..//betrag[../zweig=$zweig and ../herkunft=3]), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(sum(../..//betrag[../zweig=$zweig and ../herkunft=4]), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(sum(../..//betrag[../zweig=$zweig]), '#.##0,00', 'euro')" />
							</td>
						</tr>
					</xsl:if>
				</xsl:for-each>
				<tr class="tr">
					<td width="200" />
					<td class="bez">Auftrag-/Fördergeber-Organisation</td>
					<td colspan="4" />
				</tr>
				<tr class="tr">
					<td class="bez" rowspan="14">Insgesamt</td>
				</tr>
				<xsl:variable name="auftraggeberListe"
					select="descendant::einnahmenzeile/auftraggeber" />
				<xsl:for-each select="$auftraggeberListe">
					<xsl:sort select="." data-type="number" order="ascending" />
					<xsl:variable name="auftraggeber" select="." />
					<xsl:if
						test="generate-id() = generate-id($auftraggeberListe[. = current()][1])">
						<tr class="tr">
							<td class="bez">
								<xsl:value-of
									select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'AUFTRAGGEBER_AV' and ../RV_LOW_VALUE = $auftraggeber]" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(sum(../..//betrag[../auftraggeber=$auftraggeber and ../herkunft=2]), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(sum(../..//betrag[../auftraggeber=$auftraggeber and ../herkunft=3]), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(sum(../..//betrag[../auftraggeber=$auftraggeber and ../herkunft=4]), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(sum(../..//betrag[../auftraggeber=$auftraggeber]), '#.##0,00', 'euro')" />
							</td>
						</tr>
					</xsl:if>
				</xsl:for-each>
				<tr class="tr">
					<td class="bez">Gesamt</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(sum(.//betrag[../herkunft=2]), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(sum(.//betrag[../herkunft=3]), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(sum(.//betrag[../herkunft=4]), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of select="format-number(sum(.//betrag), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>

	<!-- 9.14 -->
	<xsl:template match="wb_9014">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="350" align="left">Wissenschafts-/Kunstzweig</th>
					<th width="150" align="left">Auftrag-/Fördergeber-Organisation</th>
					<th width="150" align="left">Sitz der Auftrag-/Fördergeber-Organisation</th>
					<th width="100" class="werte">Betrag</th>
				</tr>
				<xsl:for-each select="descendant::einnahmenzeile | descendant::erloeszeile">
					<xsl:sort select="substring(zweig, 1, 1)" order="ascending" />
					<xsl:sort select="zweig" order="ascending" />
					<xsl:sort select="auftraggeber" order="ascending" />
					<xsl:sort select="herkunft" order="ascending" />
					<xsl:variable name="zweig" select="zweig" />
					<xsl:variable name="auftraggeber" select="auftraggeber" />
					<xsl:variable name="herkunft" select="herkunft" />
					<tr class="tr">
						<td class="bez">
							<xsl:value-of select="zweig" />
							<xsl:text> </xsl:text>
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxwikuzw2014.xml')//WISSZWTEXT[../WISSZWCODE = $zweig]" />
						</td>
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'AUFTRAGGEBER_AV' and ../RV_LOW_VALUE = $auftraggeber]" />
						</td>
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'INTERNATIONAL_AV' and ../RV_LOW_VALUE = $herkunft]" />
						</td>
						<td class="werte">
							<xsl:call-template name="formatNegNumber">
								<xsl:with-param name="val" select="betrag" />
							</xsl:call-template>
							<xsl:value-of select="format-number(number(betrag), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
				<tr class="tr">
					<td class="bezgruppe">Insgesamt</td>
					<td class="bez" />
					<td class="bez" />
					<td class="werte">
						<xsl:call-template name="formatNegNumber">
							<xsl:with-param name="val" select="sum(descendant::betrag)" />
						</xsl:call-template>
						<xsl:value-of
							select="format-number(number(sum(descendant::betrag)), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 1.C.2, 1.CM.2 -->
	<xsl:template match="wb_1_C_2 | wb_1_CM_2">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr" style="border: 0px solid;">
					<th width="400" align="left" rowspan="2">Wissenschafts-/Kunstzweig</th>
					<th width="200" colspan="5">Investitionsbereich</th>
					<th width="50" class="werte" rowspan="2">Gesamt</th>
				</tr>
				<tr class="tr">
					<th>Großgeräte/Großanlagen</th>
					<th>Core Facilities</th>
					<th>Elektronische Datenbanken</th>
					<th>Räumliche Infrastruktur</th>
					<th>Sonstige Forschungsinfrastruktur</th>
				</tr>
				<xsl:variable name="zweige" select="descendant::aufwendungzeile/zweig" />
				<xsl:for-each select="$zweige">
					<xsl:sort select="." data-type="number" order="ascending" />
					<xsl:variable name="zweig" select="." />
					<xsl:if test="generate-id() = generate-id($zweige[. = current()][1])">
						<tr class="tr">
							<td class="bez">
								<xsl:value-of
									select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxwikuzw2014.xml')//WISSZWTEXT[../WISSZWCODE = $zweig]" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(sum(../..//betrag[../zweig=$zweig and ../investitionsbereich=1]), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(sum(../..//betrag[../zweig=$zweig and ../investitionsbereich=2]), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(sum(../..//betrag[../zweig=$zweig and ../investitionsbereich=3]), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(sum(../..//betrag[../zweig=$zweig and ../investitionsbereich=4]), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(sum(../..//betrag[../zweig=$zweig and ../investitionsbereich=5]), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(sum(../..//betrag[../zweig=$zweig]), '#.##0,00', 'euro')" />
							</td>
						</tr>
					</xsl:if>
				</xsl:for-each>
				<tr class="tr">
					<td class="bez">Insgesamt</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(sum(.//betrag[../investitionsbereich=1]), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(sum(.//betrag[../investitionsbereich=2]), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(sum(.//betrag[../investitionsbereich=3]), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(sum(.//betrag[../investitionsbereich=4]), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(sum(.//betrag[../investitionsbereich=5]), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of select="format-number(sum(.//betrag), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 4.1 -->
	<xsl:template match="wb_4_1">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th />
					<th colspan="2" align="center">Begutachtungstyp</th>
					<th />
				</tr>
				<tr class="tr">
					<th>Kategorien</th>
					<th align="center">
						Begutachtung im eigenen
						<br />
						Bereich
						<br />
						der Universität/
						<br />
						Medizinischen Fakultät
					</th>
					<th align="center">
						Begutachtung
						<br />
						für Externe
					</th>
					<th align="center">Gesamt</th>
				</tr>
				<xsl:variable name="studien"
					select="descendant::begutachtungszeile/studie" />
				<xsl:for-each select="$studien">
					<xsl:sort select="." order="ascending" />
					<xsl:variable name="studie" select="." />
					<xsl:if test="generate-id() = generate-id($studien[. = current()][1])">
						<tr class="tr">
							<td class="bez">
								<xsl:value-of
									select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'STUDIE_AV' and ../RV_LOW_VALUE = $studie]" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../begutachtungszeile[studie=$studie and begutachtung='1']/anzahl), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../begutachtungszeile[studie=$studie and begutachtung='3']/anzahl), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../../begutachtungszeile[studie=$studie]/anzahl)), '#.##0,00', 'euro')" />
							</td>
						</tr>
					</xsl:if>
				</xsl:for-each>
				<tr class="tr">
					<td class="bezgruppe">Insgesamt</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::begutachtung[. = '1']/../anzahl)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::begutachtung[. = '3']/../anzahl)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahl)), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>

	<!-- 4.2 -->
	<xsl:template match="wb_4_2">
		<xsl:variable name="kzidf" select="name" />
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="200" align="left">Kategorien</th>
					<th width="50" class="werte">Anzahl</th>
				</tr>
				<xsl:for-each select="descendant::teilnehmerzeile">
					<xsl:sort select="studie" order="ascending" />
					<xsl:variable name="studie" select="studie" />
					<tr class="tr">
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'STUDIE_AV' and ../RV_LOW_VALUE = $studie]" />
						</td>
						<td class="werte">
							<xsl:value-of select="format-number(number(anzahl), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
				<tr class="tr">
					<td class="bezgruppe">
						<xsl:text>Insgesamt</xsl:text>
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahl)), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>

	<!-- 4.3 -->
	<xsl:template match="wb_4_3">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="350" align="left">Dienstgeberin oder Dienstgeber</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:for-each select="descendant::dienstgeberzeile">
					<xsl:sort select="dienstgeber" order="ascending" />
					<xsl:variable name="dienstgeber" select="dienstgeber" />
					<tr class="tr">
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'DIENSTGEBER_AV' and ../RV_LOW_VALUE = $dienstgeber]" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@frauen), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@maenner), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@gesamt), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
				<tr class="tr">
					<td class="bezgruppe">Insgesamt</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen/@frauen)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen/@maenner)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen/@gesamt)), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>

	<!-- 4.4 -->
	<xsl:template match="wb_4_4">
		<xsl:variable name="kzidf" select="name" />
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="200" align="left" />
					<th width="50" class="werte">Anzahl</th>
				</tr>
				<tr class="tr">
					<td class="bezgruppe">
						<xsl:text>Insgesamt</xsl:text>
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(daten/anzahl), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>

	<!-- 5.2.6, 9.6, 9.7 -->
	<xsl:template match="db_5_2_6 | wb_9006 | wb_9007">
		<xsl:variable name="kzidf" select="name" />
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr" style="border-bottom: 0px solid;">
					<th width="200" align="left" rowspan="2">Wissenschaftliches Personal</th>
					<th colspan="3">Köpfe</th>
				</tr>
				<tr class="tr">
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<tr class="tr">
					<td class="bezgruppe">
						<xsl:text>Insgesamt</xsl:text>
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(daten/anzahlen/@frauen), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(daten/anzahlen/@maenner), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(daten/anzahlen/@gesamt), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>

	<!-- 2.A.4, 2.AM.4 -->
	<xsl:template match="wb_2_A_4 | wb_2_AM_4">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th />
					<th colspan="13" align="center">Verfahrensschritte</th>
				</tr>
				<tr class="tr">
					<th />
					<th colspan="3" align="center">angemeldet</th>
					<th colspan="3" align="center">angetreten</th>
					<th colspan="3" align="center">zulassungsberechtigt</th>
				</tr>
				<tr class="tr">
					<th width="350" align="left">Curriculum</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:variable name="zulassungen" select="descendant::zulassungzeile/isced3" />
				<xsl:for-each select="$zulassungen">
					<xsl:sort select="." order="ascending" />
					<xsl:variable name="isced" select="." />
					<xsl:if
						test="generate-id() = generate-id($zulassungen[. = current()][1])">
						<tr class="tr">
							<td class="bez">
								<xsl:value-of select="isced3" />
								<xsl:text> </xsl:text>
								<xsl:value-of
									select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxisced3.xml')//ISCEDBEZ_DT[../ISCEDKODE = $isced]" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../zulassungzeile[isced3=$isced and verfahrensschritt=1]/anzahlen/@frauen), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../zulassungzeile[isced3=$isced and verfahrensschritt=1]/anzahlen/@maenner), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../zulassungzeile[isced3=$isced and verfahrensschritt=1]/anzahlen/@gesamt), '#.##0,00', 'euro')" />
							</td>

							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../zulassungzeile[isced3=$isced and verfahrensschritt=2]/anzahlen/@frauen), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../zulassungzeile[isced3=$isced and verfahrensschritt=2]/anzahlen/@maenner), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../zulassungzeile[isced3=$isced and verfahrensschritt=2]/anzahlen/@gesamt), '#.##0,00', 'euro')" />
							</td>

							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../zulassungzeile[isced3=$isced and verfahrensschritt=3]/anzahlen/@frauen), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../zulassungzeile[isced3=$isced and verfahrensschritt=3]/anzahlen/@maenner), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../zulassungzeile[isced3=$isced and verfahrensschritt=3]/anzahlen/@gesamt), '#.##0,00', 'euro')" />
							</td>
						</tr>
					</xsl:if>
				</xsl:for-each>
				<tr class="tr">
					<td class="bezgruppe">Insgesamt</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(.//anzahlen[../verfahrensschritt=1]/@frauen)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(.//anzahlen[../verfahrensschritt=1]/@maenner)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(.//anzahlen[../verfahrensschritt=1]/@gesamt)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(.//anzahlen[../verfahrensschritt=2]/@frauen)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(.//anzahlen[../verfahrensschritt=2]/@maenner)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(.//anzahlen[../verfahrensschritt=2]/@gesamt)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(.//anzahlen[../verfahrensschritt=3]/@frauen)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(.//anzahlen[../verfahrensschritt=3]/@maenner)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(.//anzahlen[../verfahrensschritt=3]/@gesamt)), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 5.1.1 -->
	<xsl:template match="db_5_1_1">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="400" align="left" />
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:for-each select="descendant::aufwandzeile">
					<xsl:sort select="personalaufwand" order="ascending" />
					<xsl:variable name="personalaufwand" select="personalaufwand" />
					<tr class="tr">
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'PERSONALAUFWAND_AV' and ../RV_LOW_VALUE = $personalaufwand]" />
						</td>
						<td class="werte">
							<xsl:value-of select="format-number(number(betrag), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
				<tr>
					<td class="bez">Insgesamt</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::betrag)), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>

	<!-- 5.1.2 -->
	<xsl:template match="db_5_1_2">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="300" align="left">Art der Erlöse</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:for-each select="descendant::erloeszeile">
					<xsl:sort select="erloesart" order="ascending" />
					<xsl:variable name="erloesart" select="erloesart" />
					<tr class="tr">
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'ERLOESART_AV' and ../RV_LOW_VALUE = $erloesart]" />
						</td>
						<td class="werte">
							<xsl:value-of select="format-number(number(betrag), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 5.2.2 -->
	<xsl:template match="db_5_2_2">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr" style="border-bottom: 0px solid;">
					<th width="350" align="left" rowspan="2">Zeitvolumen des
						wissenschaftlichen Personals im Klinischen Bereich</th>
					<th colspan="3">Ärztinnen/Ärzte</th>
					<th colspan="3">Ärztinnen/Ärzte in Facharztausbildung</th>
					<th width="50" class="werte" rowspan="2">Gesamt</th>
				</tr>
				<tr class="tr">

					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>

				</tr>
				<xsl:variable name="zeitvolumen"
					select="descendant::zeitvolumenzeile/zeitvolumen" />
				<xsl:for-each select="$zeitvolumen">
					<xsl:sort select="." order="ascending" />
					<xsl:variable name="zeitVol" select="." />
					<xsl:if
						test="generate-id() = generate-id($zeitvolumen[. = current()][1])">
						<tr class="tr">
							<td class="bez">
								<xsl:value-of
									select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'ZEITVOLUMEN_AV' and ../RV_LOW_VALUE = $zeitVol]" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../zeitvolumenzeile[zeitvolumen=$zeitVol and personalkategorie='8']/vollzeitaequivalente/@frauen), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../zeitvolumenzeile[zeitvolumen=$zeitVol and personalkategorie='8']/vollzeitaequivalente/@maenner), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../zeitvolumenzeile[zeitvolumen=$zeitVol and personalkategorie='8']/vollzeitaequivalente/@gesamt), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../zeitvolumenzeile[zeitvolumen=$zeitVol and personalkategorie='9']/vollzeitaequivalente/@frauen), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../zeitvolumenzeile[zeitvolumen=$zeitVol and personalkategorie='9']/vollzeitaequivalente/@maenner), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(../../zeitvolumenzeile[zeitvolumen=$zeitVol and personalkategorie='9']/vollzeitaequivalente/@gesamt), '#.##0,00', 'euro')" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(sum(../../zeitvolumenzeile[zeitvolumen=$zeitVol]/vollzeitaequivalente/@gesamt)), '#.##0,00', 'euro')" />
							</td>
						</tr>
					</xsl:if>
				</xsl:for-each>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 5.2.3 -->
	<xsl:template match="db_5_2_3">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr" style="border-bottom: 0px solid;">
					<th width="350" align="left" rowspan="2">Personal im Klinischen
						Bereich</th>
					<th colspan="3">Geschlecht</th>
				</tr>
				<tr class="tr">
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:for-each select="descendant::klinperszeile">
					<xsl:sort select="personalkategorie3" order="ascending" />
					<xsl:variable name="personalkategorie3" select="personalkategorie3" />
					<tr class="tr">
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'PERSONALKATEGORIE3_AV' and ../RV_LOW_VALUE = $personalkategorie3]" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(vollzeitaequivalente/@frauen), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(vollzeitaequivalente/@maenner), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(vollzeitaequivalente/@gesamt), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 5.2.4 -->
	<xsl:template match="db_5_2_4">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="350" align="left">KMA - paktierte Investitionen</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:for-each
					select="descendant::investitionszeile | descendant::zahlungszeile">
					<xsl:sort select="kmatyp" order="ascending" />
					<xsl:variable name="kmatyp" select="kmatyp" />
					<tr class="tr">
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'KMATYP_AV' and ../RV_LOW_VALUE = $kmatyp]" />
						</td>
						<td class="werte">
							<xsl:value-of select="format-number(number(betrag), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 5.2.5 -->
	<xsl:template match="db_5_2_5">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th align="left" width="100">Kategorien</th>
					<xsl:variable name="vertragsNummern"
						select="descendant::vertragszeile/vertragsnummer" />
					<xsl:for-each select="$vertragsNummern">
						<xsl:sort select="." data-type="number" order="ascending" />
						<xsl:variable name="vertragsNummer" select="." />
						<xsl:if
							test="generate-id() = generate-id($vertragsNummern[. = current()][1])">
							<th style="padding-right: 5px;">
								Betrag Vertrag
								<xsl:value-of select="$vertragsNummer" />
							</th>
						</xsl:if>
					</xsl:for-each>
					<th>Gesamtbetrag</th>
				</tr>
				<xsl:variable name="kategorien" select="descendant::vertragszeile/kmatyp" />
				<xsl:for-each select="$kategorien">
					<xsl:sort select="." data-type="number" order="ascending" />
					<xsl:variable name="kmatyp" select="." />
					<xsl:if
						test="generate-id() = generate-id($kategorien[. = current()][1])">
						<tr class="tr">
							<td class="bez">
								<xsl:value-of
									select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'KMATYP_AV' and ../RV_LOW_VALUE = $kmatyp]" />
							</td>
							<!-- Verträge -->
							<xsl:variable name="vertragsNummern"
								select="../..//vertragszeile/vertragsnummer" />
							<xsl:for-each select="$vertragsNummern">
								<xsl:sort select="." data-type="number" order="ascending" />
								<xsl:variable name="vertragsNummer" select="." />
								<xsl:if
									test="generate-id() = generate-id($vertragsNummern[. = current()][1])">
									<td class="werte" style="padding-right: 5px;">
										<xsl:value-of
											select="format-number(sum(../..//betrag[../kmatyp=$kmatyp and ../vertragsnummer=$vertragsNummer]), '#.##0,00', 'euro')" />
									</td>
								</xsl:if>
							</xsl:for-each>
							<!-- Gesamtbetrag -->
							<td class="werte">
								<xsl:value-of
									select="format-number(sum(../..//betrag[../kmatyp=$kmatyp]), '#.##0,00', 'euro')" />
							</td>
						</tr>
					</xsl:if>
				</xsl:for-each>
				<tr class="tr">
					<td class="bez">Gesamt</td>
					<!-- Verträge -->
					<xsl:variable name="vertragsNummern"
						select="../..//vertragszeile/vertragsnummer" />
					<xsl:for-each select="$vertragsNummern">
						<xsl:sort select="." data-type="number" order="ascending" />
						<xsl:variable name="vertragsNummer" select="." />
						<xsl:if
							test="generate-id() = generate-id($vertragsNummern[. = current()][1])">
							<td class="werte" style="padding-right: 5px;">
								<xsl:value-of
									select="format-number(sum(../..//betrag[../vertragsnummer=$vertragsNummer]), '#.##0,00', 'euro')" />
							</td>
						</xsl:if>
					</xsl:for-each>
					<!-- Gesamtbetrag -->
					<td class="werte">
						<xsl:value-of select="format-number(sum(.//betrag), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 9.1 -->
	<xsl:template match="wb_9001">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="350" align="left">Studienkategorie</th>
					<th width="350" align="left">Personenmenge</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:for-each select="descendant::studierendezeile">
					<xsl:sort select="studienkategorie" order="ascending" />
					<xsl:sort select="personenmenge" order="ascending" />
					<xsl:variable name="studienkategorie" select="studienkategorie" />
					<xsl:variable name="personenmenge" select="personenmenge" />
					<tr class="tr">
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'STUDIENKATEGORIE_AV' and ../RV_LOW_VALUE = $studienkategorie]" />
						</td>
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'STUDIERENDE_AV' and ../RV_LOW_VALUE = $personenmenge]" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@frauen), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@maenner), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@gesamt), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
				<tr class="tr">
					<td class="bezgruppe">Insgesamt</td>
					<td class="bezgruppe" />
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen/@frauen)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen/@maenner)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen/@gesamt)), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 9.2, 9.3 -->
	<xsl:template match="wb_9002 | wb_9003">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="350" align="left">Studienkategorie</th>
					<th width="350" align="left">Studienart</th>
					<th width="350" align="left">Eingerichtetes Studium</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:for-each select="descendant::studienzeile">
					<xsl:sort select="studienkategorie" order="ascending" />
					<xsl:sort select="studienart" order="ascending" />
					<xsl:sort select="eingerichtetes_studium" order="ascending" />
					<xsl:variable name="studienkategorie" select="studienkategorie" />
					<xsl:variable name="studienart" select="studienart" />
					<xsl:variable name="eingerichtetes_studium" select="eingerichtetes_studium" />
					<tr class="tr">
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'STUDIENKATEGORIE_AV' and ../RV_LOW_VALUE = $studienkategorie]" />
						</td>
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'STUDIENART_AV' and ../RV_LOW_VALUE = $studienart]" />
						</td>
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxstudien.xml')//BEZEICHNUNG[../EINGER_STUDIUM_IDF = $eingerichtetes_studium]" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@frauen), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@maenner), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@gesamt), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
				<tr class="tr">
					<td class="bezgruppe">Insgesamt</td>
					<td class="bezgruppe" />
					<td class="bezgruppe" />
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen/@frauen)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen/@maenner)), '#.##0,00', 'euro')" />
					</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahlen/@gesamt)), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 9.4, 9.5 -->
	<xsl:template match="wb_9004 | wb_9005">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="350" align="left">Belegte Studien</th>
					<th width="100" align="left">Staatsangehörigkeit</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:for-each select="descendant::studienzeile">
					<xsl:sort select="studienart" order="ascending" />
					<xsl:sort select="staatsangehoerigkeit" order="ascending" />
					<xsl:variable name="studienart" select="studienart" />
					<xsl:variable name="staatsangehoerigkeit" select="staatsangehoerigkeit" />
					<tr class="tr">
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'STUDIENART_AV' and ../RV_LOW_VALUE = $studienart]" />
						</td>
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'STAATSANGEHOERIGKEIT_AV' and ../RV_LOW_VALUE = $staatsangehoerigkeit]" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@frauen), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@maenner), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@gesamt), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 9.8 -->
	<xsl:template match="wb_9008">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="300" align="left">Unternehmenszweck</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:for-each select="descendant::beteiligungszeile">
					<xsl:sort select="unternehmenszweck" order="ascending" />
					<xsl:variable name="unternehmenszweck" select="unternehmenszweck" />
					<tr class="tr">
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'UNTERNEHMENSZWECK_AV' and ../RV_LOW_VALUE = $unternehmenszweck]" />
						</td>
						<td class="werte">
							<xsl:value-of select="format-number(number(anzahl), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
				<tr class="tr">
					<td class="bezgruppe">Insgesamt</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahl)), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 9.9 -->
	<xsl:template match="wb_9009">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th />
					<th />
					<th colspan="3">Anzahlen</th>
					<th colspan="3">Vollzeitäquivalente</th>
				</tr>
				<tr class="tr">
					<th width="350" align="left">Personalzuordnung</th>
					<th width="350" align="left">Personalkategorie</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
					<th width="50" class="werte">Frauen</th>
					<th width="50" class="werte">Männer</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:for-each select="descendant::personalzeile">
					<xsl:sort select="personalzuordnung" order="ascending" />
					<xsl:sort select="personalkategorie" order="ascending" />
					<xsl:variable name="personalzuordnung" select="personalzuordnung" />
					<xsl:variable name="personalkategorie" select="personalkategorie" />
					<tr class="tr">
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'PERSONALZUORDNUNG_AV' and ../RV_LOW_VALUE = $personalzuordnung]" />
						</td>
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'PERSONALKATEGORIE5_AV' and ../RV_LOW_VALUE = $personalkategorie]" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@frauen), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@maenner), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(anzahlen/@gesamt), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(vollzeitaequivalente/@frauen), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(vollzeitaequivalente/@maenner), '#.##0,00', 'euro')" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(vollzeitaequivalente/@gesamt), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 9.10 -->
	<xsl:key name="kBetLeistung" match="personalzeile[ancestor::wb_9010]"
		use="betriebsleistung" />
	<xsl:template match="wb_9010">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="350" align="left">Betriebsleistung</th>
					<th width="350" align="left">Rechnungskreis</th>
					<th width="100" class="werte">Betrag</th>
				</tr>
				<xsl:for-each
					select="descendant::personalzeile[generate-id(.) = generate-id(key('kBetLeistung', betriebsleistung)[position() = 1])]">
					<xsl:sort select="betriebsleistung" order="ascending" />
					<xsl:variable name="betriebsleistung" select="betriebsleistung" />
					<xsl:for-each select="key('kBetLeistung', betriebsleistung)">
						<xsl:sort select="rechnungskreis" order="ascending" />
						<xsl:variable name="rechnungskreis" select="rechnungskreis" />
						<tr class="tr">
							<td class="bez">
								<xsl:value-of
									select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'BETRIEBSLEISTUNG_AV' and ../RV_LOW_VALUE = $betriebsleistung]" />
							</td>
							<td class="bez">
								<xsl:value-of
									select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'RECHNUNGSKREIS_AV' and ../RV_LOW_VALUE = $rechnungskreis]" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(betrag), '#.##0,00', 'euro')" />
							</td>
						</tr>
					</xsl:for-each>
					<tr class="tr">
						<td class="bezgruppe" colspan="2">
							<xsl:text>Summe </xsl:text>
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'BETRIEBSLEISTUNG_AV' and ../RV_LOW_VALUE = $betriebsleistung]" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(sum(key('kBetLeistung', betriebsleistung)/betrag)), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 9.12 -->
	<xsl:key name="kPubZuord" match="publikationszeile[ancestor::wb_9012]"
		use="publikationszuordnung" />
	<xsl:template match="wb_9012">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="350" align="left">Publikationszuordnung</th>
					<th width="350" align="left">Publikationstyp</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:for-each
					select="descendant::publikationszeile[generate-id(.) = generate-id(key('kPubZuord', publikationszuordnung)[position() = 1])]">
					<xsl:sort select="publikationszuordnung" order="ascending" />
					<xsl:variable name="publikationszuordnung" select="publikationszuordnung" />
					<xsl:for-each select="key('kPubZuord', publikationszuordnung)">
						<xsl:sort select="publikationstyp" order="ascending" />
						<xsl:variable name="publikationstyp" select="publikationstyp" />
						<tr class="tr">
							<td class="bez">
								<xsl:value-of
									select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'PUBLIKATIONSZUORDNUNG_AV' and ../RV_LOW_VALUE = $publikationszuordnung]" />
							</td>
							<td class="bez">
								<xsl:value-of
									select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'PUBLIKATIONSTYP_AV' and ../RV_LOW_VALUE = $publikationstyp]" />
							</td>
							<td class="werte">
								<xsl:value-of
									select="format-number(number(anzahl), '#.##0,00', 'euro')" />
							</td>
						</tr>
					</xsl:for-each>
					<tr class="tr">
						<td class="bezgruppe" colspan="2">
							<xsl:text>Summe </xsl:text>
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'PUBLIKATIONSZUORDNUNG_AV' and ../RV_LOW_VALUE = $publikationszuordnung]" />
						</td>
						<td class="werte">
							<xsl:value-of
								select="format-number(number(sum(key('kPubZuord', publikationszuordnung)/anzahl)), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 9.15 -->
	<xsl:template match="wb_9015">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="350" align="left">Wissenschafts-/Kunstzweig</th>
					<th width="150" align="left">Publikationstyp</th>
					<th width="150" align="left">Publikationszuordnung</th>
					<th width="100" class="werte">Gesamt</th>
				</tr>
				<xsl:for-each select="descendant::publikationszeile">
					<xsl:sort select="substring(zweig, 1, 1)" order="ascending" />
					<xsl:sort select="zweig" order="ascending" />
					<xsl:sort select="publikationstyp" order="ascending" />
					<xsl:sort select="publikationszuordnung" order="ascending" />
					<xsl:variable name="zweig" select="zweig" />
					<xsl:variable name="publikationstyp" select="publikationstyp" />
					<xsl:variable name="publikationszuordnung" select="publikationszuordnung" />
					<tr class="tr">
						<td class="bez">
							<xsl:value-of select="zweig" />
							<xsl:text> </xsl:text>
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxwikuzw2014.xml')//WISSZWTEXT[../WISSZWCODE = $zweig]" />
						</td>
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'PUBLIKATIONSTYP_AV' and ../RV_LOW_VALUE = $publikationstyp]" />
						</td>
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'PUBLIKATIONSZUORDNUNG_AV' and ../RV_LOW_VALUE = $publikationszuordnung]" />
						</td>
						<td class="werte">
							<xsl:value-of select="format-number(number(anzahl), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
				<tr class="tr">
					<td class="bezgruppe">Insgesamt</td>
					<td class="bez" />
					<td class="bez" />
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahl)), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 9.16 -->
	<xsl:template match="wb_9016">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="300" align="left">Patentanzahl</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:for-each select="descendant::patentzeile">
					<xsl:sort select="patentanzahl" order="ascending" />
					<xsl:variable name="patentanzahl" select="patentanzahl" />
					<tr class="tr">
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'PATENTANZAHL_AV' and ../RV_LOW_VALUE = $patentanzahl]" />
						</td>
						<td class="werte">
							<xsl:value-of select="format-number(number(anzahl), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
				<tr class="tr">
					<td class="bezgruppe">Insgesamt</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahl)), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
	<!-- 9.17 -->
	<xsl:template match="wb_9017">
		<xsl:call-template name="printKZKopf" />
		<table class="table">
			<tbody>
				<tr class="tr">
					<th width="300" align="left">Outputkategorie</th>
					<th width="50" class="werte">Gesamt</th>
				</tr>
				<xsl:for-each select="descendant::outputzeile">
					<xsl:sort select="outputkategorie" order="ascending" />
					<xsl:variable name="outputkategorie" select="outputkategorie" />
					<tr class="tr">
						<td class="bez">
							<xsl:value-of
								select="document('http://wissensbilanz.noc-science.at/wibi/2016/codxrefcodes.xml')//RV_MEANING[../RV_DOMAIN = 'OUTPUTKATEGORIE_AV' and ../RV_LOW_VALUE = $outputkategorie]" />
						</td>
						<td class="werte">
							<xsl:value-of select="format-number(number(anzahl), '#.##0,00', 'euro')" />
						</td>
					</tr>
				</xsl:for-each>
				<tr class="tr">
					<td class="bezgruppe">Insgesamt</td>
					<td class="werte">
						<xsl:value-of
							select="format-number(number(sum(descendant::anzahl)), '#.##0,00', 'euro')" />
					</td>
				</tr>
			</tbody>
		</table>
		<xsl:call-template name="printInterpret" />
	</xsl:template>
</xsl:stylesheet>
